==> ci-game-1.14-sources.jar: hudson/plugins/cigame/rules/plugins/violation/Messages.java <==
// CHECKSTYLE:OFF

package hudson.plugins.cigame.rules.plugins.violation;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;

@SuppressWarnings({
    "",
    "PMD"
})
public class Messages {

    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * Violations
     * 
     */
    public static String ViolationRuleSet_Title() {
        return holder.format("ViolationRuleSet.Title");
    }

    /**
     * Violations
     * 
     */
    public static Localizable _ViolationRuleSet_Title() {
        return new Localizable(holder, "ViolationRuleSet.Title");
    }

    /**
     * FindBugs violation
     * 
     */
    public static String ViolationRuleSet_FindBugsRule_Name() {
        return holder.format("ViolationRuleSet.FindBugsRule.Name");
    }

    /**
     * FindBugs violation
     * 
     */
    public static Localizable _ViolationRuleSet_FindBugsRule_Name() {
        return new Localizable(holder, "ViolationRuleSet.FindBugsRule.Name");
    }

    /**
     * Checkstyle violation
     * 
     */
    public static String ViolationRuleSet_CheckstyleRule_Name() {
        return holder.format("ViolationRuleSet.CheckstyleRule.Name");
    }

    /**
     * Checkstyle violation
     * 
     */
    public static Localizable _ViolationRuleSet_CheckstyleRule_Name() {
        return new Localizable(holder, "ViolationRuleSet.CheckstyleRule.Name");
    }

    /**
     * {0} new {1} were found
     * 
     */
    public static String ViolationRuleSet_DefaultRule_NewViolationsCount(Object arg1, Object arg2) {
        return holder.format("ViolationRuleSet.DefaultRule.NewViolationsCount", arg1, arg2);
    }

    /**
     * {0} new {1} were found
     * 
     */
    public static Localizable _ViolationRuleSet_DefaultRule_NewViolationsCount(Object arg1, Object arg2) {
        return new Localizable(holder, "ViolationRuleSet.DefaultRule.NewViolationsCount", arg1, arg2);
    }

    /**
     * CPD violation
     * 
     */
    public static String ViolationRuleSet_CpdRule_Name() {
        return holder.format("ViolationRuleSet.CpdRule.Name");
    }

    /**
     * CPD violation
     * 
     */
    public static Localizable _ViolationRuleSet_CpdRule_Name() {
        return new Localizable(holder, "ViolationRuleSet.CpdRule.Name");
    }

    /**
     * {0} {1} were fixed
     * 
     */
    public static String ViolationRuleSet_DefaultRule_FixedViolationsCount(Object arg1, Object arg2) {
        return holder.format("ViolationRuleSet.DefaultRule.FixedViolationsCount", arg1, arg2);
    }

    /**
     * {0} {1} were fixed
     * 
     */
    public static Localizable _ViolationRuleSet_DefaultRule_FixedViolationsCount(Object arg1, Object arg2) {
        return new Localizable(holder, "ViolationRuleSet.DefaultRule.FixedViolationsCount", arg1, arg2);
    }

    /**
     * FXCop violation
     * 
     */
    public static String ViolationRuleSet_FxcopRule_Name() {
        return holder.format("ViolationRuleSet.FxcopRule.Name");
    }

    /**
     * FXCop violation
     * 
     */
    public static Localizable _ViolationRuleSet_FxcopRule_Name() {
        return new Localizable(holder, "ViolationRuleSet.FxcopRule.Name");
    }

    /**
     * PMD violation
     * 
     */
    public static String ViolationRuleSet_PmdRule_Name() {
        return holder.format("ViolationRuleSet.PmdRule.Name");
    }

    /**
     * PMD violation
     * 
     */
    public static Localizable _ViolationRuleSet_PmdRule_Name() {
        return new Localizable(holder, "ViolationRuleSet.PmdRule.Name");
    }

    /**
     * Simian violation
     * 
     */
    public static String ViolationRuleSet_SimianRule_Name() {
        return holder.format("ViolationRuleSet.SimianRule.Name");
    }

    /**
     * Simian violation
     * 
     */
    public static Localizable _ViolationRuleSet_SimianRule_Name() {
        return new Localizable(holder, "ViolationRuleSet.SimianRule.Name");
    }

    /**
     * pylint violation
     * 
     */
    public static String ViolationRuleSet_PylintRule_Name() {
        return holder.format("ViolationRuleSet.PylintRule.Name");
    }

    /**
     * pylint violation
     * 
     */
    public static Localizable _ViolationRuleSet_PylintRule_Name() {
        return new Localizable(holder, "ViolationRuleSet.PylintRule.Name");
    }

}

==> ci-game-1.17-sources.jar: hudson/plugins/cigame/rules/plugins/violation/Messages.java <==
// CHECKSTYLE:OFF

package hudson.plugins.cigame.rules.plugins.violation;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;

@SuppressWarnings({
    "",
    "PMD"
})
public class Messages {

    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * Violations
     * 
     */
    public static String ViolationRuleSet_Title() {
        return holder.format("ViolationRuleSet.Title");
    }

    /**
     * Violations
     * 
     */
    public static Localizable _ViolationRuleSet_Title() {
        return new Localizable(holder, "ViolationRuleSet.Title");
    }

    /**
     * FindBugs violation
     * 
     */
    public static String ViolationRuleSet_FindBugsRule_Name() {
        return holder.format("ViolationRuleSet.FindBugsRule.Name");
    }

    /**
     * FindBugs violation
     * 
     */
    public static Localizable _ViolationRuleSet_FindBugsRule_Name() {
        return new Localizable(holder, "ViolationRuleSet.FindBugsRule.Name");
    }

    /**
     * Checkstyle violation
     * 
     */
    public static String ViolationRuleSet_CheckstyleRule_Name() {
        return holder.format("ViolationRuleSet.CheckstyleRule.Name");
    }

    /**
     * Checkstyle violation
     * 
     */
    public static Localizable _ViolationRuleSet_CheckstyleRule_Name() {
        return new Localizable(holder, "ViolationRuleSet.CheckstyleRule.Name");
    }

    /**
     * StyleCop violation
     * 
     */
    public static String ViolationRuleSet_StylecopRule_Name() {
        return holder.format("ViolationRuleSet.StylecopRule.Name");
    }

    /**
     * StyleCop violation
     * 
     */
    public static Localizable _ViolationRuleSet_StylecopRule_Name() {
        return new Localizable(holder, "ViolationRuleSet.StylecopRule.Name");
    }

    /**
     * {0} new {1} were found
     * 
     */
    public static String ViolationRuleSet_DefaultRule_NewViolationsCount(Object arg1, Object arg2) {
        return holder.format("ViolationRuleSet.DefaultRule.NewViolationsCount", arg1, arg2);
    }

    /**
     * {0} new {1} were found
     * 
     */
    public static Localizable _ViolationRuleSet_DefaultRule_NewViolationsCount(Object arg1, Object arg2) {
        return new Localizable(holder, "ViolationRuleSet.DefaultRule.NewViolationsCount", arg1, arg2);
    }

    /**
     * CPD violation
     * 
     */
    public static String ViolationRuleSet_CpdRule_Name() {
        return holder.format("ViolationRuleSet.CpdRule.Name");
    }

    /**
     * CPD violation
     * 
     */
    public static Localizable _ViolationRuleSet_CpdRule_Name() {
        return new Localizable(holder, "ViolationRuleSet.CpdRule.Name");
    }

    /**
     * {0} {1} were fixed
     * 
     */
    public static String ViolationRuleSet_DefaultRule_FixedViolationsCount(Object arg1, Object arg2) {
        return holder.format("ViolationRuleSet.DefaultRule.FixedViolationsCount", arg1, arg2);
    }

    /**
     * {0} {1} were fixed
     * 
     */
    public static Localizable _ViolationRuleSet_DefaultRule_FixedViolationsCount(Object arg1, Object arg2) {
        return new Localizable(holder, "ViolationRuleSet.DefaultRule.FixedViolationsCount", arg1, arg2);
    }

    /**
     * FXCop violation
     * 
     */
    public static String ViolationRuleSet_FxcopRule_Name() {
        return holder.format("ViolationRuleSet.FxcopRule.Name");
    }

    /**
     * FXCop violation
     * 
     */
    public static Localizable _ViolationRuleSet_FxcopRule_Name() {
        return new Localizable(holder, "ViolationRuleSet.FxcopRule.Name");
    }

    /**
     * PMD violation
     * 
     */
    public static String ViolationRuleSet_PmdRule_Name() {
        return holder.format("ViolationRuleSet.PmdRule.Name");
    }

    /**
     * PMD violation
     * 
     */
    public static Localizable _ViolationRuleSet_PmdRule_Name() {
        return new Localizable(holder, "ViolationRuleSet.PmdRule.Name");
    }

    /**
     * Simian violation
     * 
     */
    public static String ViolationRuleSet_SimianRule_Name() {
        return holder.format("ViolationRuleSet.SimianRule.Name");
    }

    /**
     * Simian violation
     * 
     */
    public static Localizable _ViolationRuleSet_SimianRule_Name() {
        return new Localizable(holder, "ViolationRuleSet.SimianRule.Name");
    }

    /**
     * pylint violation
     * 
     */
    public static String ViolationRuleSet_PylintRule_Name() {
        return holder.format("ViolationRuleSet.PylintRule.Name");
    }

    /**
     * pylint violation
     * 
     */
    public static Localizable _ViolationRuleSet_PylintRule_Name() {
        return new Localizable(holder, "ViolationRuleSet.PylintRule.Name");
    }

}
